==> remote-booter-2014.7.9-sources.jar: com/xebialabs/deployit/booter/remote/execution/RemoteStepState.java <==
package com.xebialabs.deployit.booter.remote.execution;

import java.util.HashMap;
import java.util.Map;

import org.joda.time.DateTime;

import com.xebialabs.deployit.engine.api.execution.StepExecutionState;
import com.xebialabs.deployit.engine.api.execution.StepState;

public class RemoteStepState implements StepState {
    private String description;
    private StepExecutionState state;
    private String log;
    private DateTime startDate;
    private DateTime completionDate;
    private int failureCount;

    private Map<String, String> metadata = new HashMap<String, String>();

    @Override
    public String getDescription() {
        return description;
    }

    @Override
    public StepExecutionState getState() {
        return state;
    }

    @Override
    public String getLog() {
        return log;
    }

    @Override
    public DateTime getStartDate() {
        return startDate;
    }

    @Override
    public DateTime getCompletionDate() {
        return completionDate;
    }

    @Override
    public int getFailureCount() {
        return failureCount;
    }

    @Override
    public Map<String, String> getMetadata() {
        return metadata;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public void setState(StepExecutionState state) {
        this.state = state;
    }

    public void setLog(String log) {
        this.log = log;
    }

    public void setStartDate(DateTime startDate) {
        this.startDate = startDate;
    }

    public void setCompletionDate(DateTime completionDate) {
        this.completionDate = completionDate;
    }

    public void setFailureCount(int failureCount) {
        this.failureCount = failureCount;
    }

    public void setMetadata(Map<String, String> metadata) {
        this.metadata = metadata;
    }

    @Override
    public String toString() {
        return description;
    }
}

==> remote-booter-2015.6.1-sources.jar: com/xebialabs/deployit/booter/remote/execution/RemoteStepState.java <==
/**
 * Copyright © 2014-2015 XebiaLabs B.V. and its affiliates. Use is subject to terms of the enclosed Legal Notice.
 */
package com.xebialabs.deployit.booter.remote.execution;

import java.util.HashMap;
import java.util.Map;
import org.joda.time.DateTime;

import com.xebialabs.deployit.engine.api.execution.StepExecutionState;
import com.xebialabs.deployit.engine.api.execution.StepState;

public class RemoteStepState implements StepState {
    private String description;
    private StepExecutionState state;
    private String log;
    private DateTime startDate;
    private DateTime completionDate;
    private int failureCount;

    private Map<String, String> metadata = new HashMap<>();

    @Override
    public String getDescription() {
        return description;
    }

    @Override
    public StepExecutionState getState() {
        return state;
    }

    @Override
    public String getLog() {
        return log;
    }

    @Override
    public DateTime getStartDate() {
        return startDate;
    }

    @Override
    public DateTime getCompletionDate() {
        return completionDate;
    }

    @Override
    public int getFailureCount() {
        return failureCount;
    }

    @Override
    public Map<String, String> getMetadata() {
        return metadata;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public void setState(StepExecutionState state) {
        this.state = state;
    }

    public void setLog(String log) {
        this.log = log;
    }

    public void setStartDate(DateTime startDate) {
        this.startDate = startDate;
    }

    public void setCompletionDate(DateTime completionDate) {
        this.completionDate = completionDate;
    }

    public void setFailureCount(int failureCount) {
        this.failureCount = failureCount;
    }

    public void setMetadata(Map<String, String> metadata) {
        this.metadata = metadata;
    }

    @Override
    public String toString() {
        return description;
    }
}
